==> vlc-1.2.0-pre4.tar.xz: vlc-1.2.0-pre4/modules/stream_filter/dash/adaptationlogic/AbstractAdaptationLogic.cpp <==
/*
 * AbstractAdaptationLogic.cpp
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "AbstractAdaptationLogic.h"

using namespace dash::logic;
using namespace dash::xml;
using namespace dash::mpd;
using namespace dash::exception;

AbstractAdaptationLogic::AbstractAdaptationLogic    (IMPDManager *mpdManager)
{
    this->bpsAvg        = 0;
    this->bpsLastChunk  = 0;
    this->mpdManager    = mpdManager;
}
AbstractAdaptationLogic::~AbstractAdaptationLogic   ()
{
}

void AbstractAdaptationLogic::downloadRateChanged    (long bpsAvg, long bpsLastChunk)
{
    this->bpsAvg        = bpsAvg;
    this->bpsLastChunk  = bpsLastChunk;
}
long AbstractAdaptationLogic::getBpsAvg              ()
{
    return this->bpsAvg;
}
long AbstractAdaptationLogic::getBpsLastChunk        ()
{
    return this->bpsLastChunk;
}

==> vlc-2.0.7.tar.xz: vlc-2.0.7/modules/stream_filter/dash/adaptationlogic/AbstractAdaptationLogic.cpp <==
/*
 * AbstractAdaptationLogic.cpp
 *****************************************************************************
 * Copyright (C) 2010 - 2011 Klagenfurt University
 *
 * Created on: Aug 10, 2010
 * Authors: Christopher Mueller <christopher.mueller@itec.uni-klu.ac.at>
 *          Christian Timmerer  <christian.timmerer@itec.uni-klu.ac.at>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif

#include "AbstractAdaptationLogic.h"

using namespace dash::logic;
using namespace dash::xml;
using namespace dash::mpd;
using namespace dash::exception;

AbstractAdaptationLogic::AbstractAdaptationLogic    (IMPDManager *mpdManager)
{
    this->bpsAvg        = -1;
    this->bpsLastChunk  = 0;
    this->mpdManager    = mpdManager;
}
AbstractAdaptationLogic::~AbstractAdaptationLogic   ()
{
}

void AbstractAdaptationLogic::downloadRateChanged    (long bpsAvg, long bpsLastChunk)
{
    this->bpsAvg        = bpsAvg;
    this->bpsLastChunk  = bpsLastChunk;
}
long AbstractAdaptationLogic::getBpsAvg              ()
{
    return this->bpsAvg;
}
long AbstractAdaptationLogic::getBpsLastChunk        ()
{
    return this->bpsLastChunk;
}
